@@ -1,6 +1,7 @@
 import pyautogui as pyautogui
 import string
 from ..utils.utils import resource_path
+from ..utils.utils import split
 from time import sleep
 
 secs_between_keys = 0.1
@@ -11,8 +12,8 @@ class Ui_tools:
     @staticmethod
     def getPosition(image: string):
         try:
-            return pyautogui.locateCenterOnScreen(image, grayscale=True, confidence=.9)
-        except TypeError as e:
+            return pyautogui.locateCenterOnScreen(image, grayscale=True, confidence=.8)
+        except:
             return None
 
     @staticmethod
@@ -33,5 +34,5 @@ class Ui_tools:
 
     @staticmethod
     def type(text: string):
-        pyautogui.typewrite([text], interval=secs_between_keys)
+        pyautogui.typewrite(split(text), interval=secs_between_keys)
         sleep(secs_after_action)
